@@ -377,7 +377,7 @@ int iso15693_read_single_block(iso15693_t* iso15693, const rfid_transponder_t* t
 {
   u_int8_t request[ISO15693_UID_SIZE + ISO15693_BLOCK_NUMBER_SIZE];
   int request_length;
-  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->private;
+  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->opaque;
   u_int8_t flags = 0;
   int index = 0;
   int want_security_status = block->security_status;
@@ -447,7 +447,7 @@ int iso15693_write_single_block(iso15693_t* iso15693, const rfid_transponder_t*
 {
   u_int8_t request[ISO15693_UID_SIZE + ISO15693_BLOCK_NUMBER_SIZE + ISO15693_BLOCK_SIZE_MAX];
   int request_length;
-  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->private;
+  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->opaque;
   u_int8_t flags = 0;
   int index = 0;
   u_int8_t* buffer = 0;
@@ -494,7 +494,7 @@ static int read_multiple_blocks(iso15693_t* iso15693, const rfid_transponder_t*
 {
   u_int8_t request[ISO15693_UID_SIZE + ISO15693_BLOCK_NUMBER_SIZE + ISO15693_BLOCK_NUMBER_SIZE];
   int request_length;
-  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->private;
+  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->opaque;
   u_int8_t flags = 0;
   int index = 0;
   int want_security_status = blocks[0].security_status;
@@ -601,7 +601,7 @@ static int write_multiple_blocks(iso15693_t* iso15693, const rfid_transponder_t*
 {
   u_int8_t* request;
   int request_length = ISO15693_UID_SIZE + ISO15693_BLOCK_NUMBER_SIZE + ISO15693_BLOCK_NUMBER_SIZE + blocks_length * transponder->bytes_per_block;
-  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->private;
+  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->opaque;
   u_int8_t flags = 0;
   int block_start = blocks[0].block_number & 0xFF;
   int index = 0;
@@ -689,7 +689,7 @@ int iso15693_lock_block(iso15693_t* iso15693, const rfid_transponder_t* transpon
 {
   u_int8_t request[ISO15693_UID_SIZE + ISO15693_BLOCK_NUMBER_SIZE];
   int request_length;
-  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->private;
+  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->opaque;
   u_int8_t flags = 0;
   int index = 0;
   u_int8_t* buffer = 0;
@@ -741,7 +741,7 @@ int iso15693_write_afi(iso15693_t* iso15693, const rfid_transponder_t* transpond
 {
   u_int8_t request[ISO15693_UID_SIZE + ISO15693_AFI_SIZE];
   int request_length;
-  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->private;
+  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->opaque;
   u_int8_t flags = 0;
   int index = 0;
   u_int8_t* buffer = 0;
@@ -787,7 +787,7 @@ int iso15693_write_dsfid(iso15693_t* iso15693, const rfid_transponder_t* transpo
 {
   u_int8_t request[ISO15693_UID_SIZE + ISO15693_AFI_SIZE];
   int request_length;
-  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->private;
+  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->opaque;
   u_int8_t flags = 0;
   int index = 0;
   u_int8_t* buffer = 0;
@@ -836,7 +836,7 @@ int iso15693_get_system_information(iso15693_t* iso15693, rfid_transponder_t* tr
 {
   u_int8_t request[ISO15693_UID_SIZE];
   int request_length;
-  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->private;
+  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->opaque;
   u_int8_t flags = 0;
   int index = 0;
   u_int8_t* buffer = 0;
@@ -1096,7 +1096,7 @@ int iso15693_get_multiple_block_security_status(iso15693_t* iso15693, const u_in
 
 int iso15693_response_size(rfid_reader_t* reader, u_int8_t* request, int request_size, int* response_size, const rfid_transponder_t* transponder)
 {
-  iso15693_t* iso15693 = (iso15693_t*)reader->private;
+  iso15693_t* iso15693 = (iso15693_t*)reader->opaque;
 
   switch(request[ISO15693_COMMAND_INDEX]) {
   case ISO15693_COMMAND_INVENTORY:
@@ -1173,7 +1173,7 @@ int iso15693_response_size(rfid_reader_t* reader, u_int8_t* request, int request
 
 static const char* drv_version(struct rfid_reader* reader)
 {
-  iso15693_t* iso15693 = (iso15693_t*)reader->private;
+  iso15693_t* iso15693 = (iso15693_t*)reader->opaque;
   rfid_reader_t* driver = iso15693->reader;
   const char* driver_version = driver ? driver->version_f(driver) : "(no driver)";
   static char* version = 0;
@@ -1189,7 +1189,7 @@ static const char* drv_version(struct rfid_reader* reader)
 
 static void drv_verbose(struct rfid_reader* reader, int verbosity)
 {
-  iso15693_t* iso15693 = (iso15693_t*)reader->private;
+  iso15693_t* iso15693 = (iso15693_t*)reader->opaque;
   rfid_reader_t* driver = iso15693->reader;
 
   iso15693->verbose = verbosity;
@@ -1223,7 +1223,7 @@ static int driver_load(iso15693_t* iso15693, const char* drivers)
 
 static int drv_probe(struct rfid_reader* reader, const char* drivers)
 {
-  iso15693_t* iso15693 = (iso15693_t*)reader->private;
+  iso15693_t* iso15693 = (iso15693_t*)reader->opaque;
   int retval;
 
   iso15693->io = reader->io;
@@ -1246,7 +1246,7 @@ static int drv_probe(struct rfid_reader* reader, const char* drivers)
 
 static int drv_init(struct rfid_reader* reader, const char* drivers)
 {
-  iso15693_t* iso15693 = (iso15693_t*)reader->private;
+  iso15693_t* iso15693 = (iso15693_t*)reader->opaque;
   iso15693->io = reader->io;
 
   strcpy(reader->drivers, drivers);
@@ -1262,7 +1262,7 @@ static int drv_init(struct rfid_reader* reader, const char* drivers)
 
 static void drv_end(struct rfid_reader* reader)
 {
-  iso15693_t* iso15693 = (iso15693_t*)reader->private;
+  iso15693_t* iso15693 = (iso15693_t*)reader->opaque;
   rfid_reader_t* driver = iso15693->reader;
 
   {
@@ -1286,7 +1286,7 @@ static void drv_end(struct rfid_reader* reader)
 
 static char* drv_strerror(struct rfid_reader* reader)
 {
-  iso15693_t* iso15693 = (iso15693_t*)reader->private;
+  iso15693_t* iso15693 = (iso15693_t*)reader->opaque;
   rfid_reader_t* driver = iso15693->reader;
   char* message = (char*)malloc(512);
 
@@ -1305,7 +1305,7 @@ static char* drv_strerror(struct rfid_reader* reader)
 
 static int drv_error(struct rfid_reader* reader)
 {
-  iso15693_t* iso15693 = (iso15693_t*)reader->private;
+  iso15693_t* iso15693 = (iso15693_t*)reader->opaque;
   rfid_reader_t* driver = iso15693->reader;
 
   if(iso15693->error) {
@@ -1317,7 +1317,7 @@ static int drv_error(struct rfid_reader* reader)
 
 static int drv_read(struct rfid_reader* reader, int block_start, int number_of_blocks, rfid_transponder_t* transponder)
 {
-  iso15693_t* iso15693 = (iso15693_t*)reader->private;
+  iso15693_t* iso15693 = (iso15693_t*)reader->opaque;
   rfid_block_t* blocks;
   int i;
   u_int8_t* pointer;
@@ -1361,7 +1361,7 @@ static int drv_read(struct rfid_reader* reader, int block_start, int number_of_b
 
 static int drv_write(struct rfid_reader* reader, int block_start, int number_of_blocks, rfid_transponder_t* transponder)
 {
-  iso15693_t* iso15693 = (iso15693_t*)reader->private;
+  iso15693_t* iso15693 = (iso15693_t*)reader->opaque;
   u_int8_t* pointer;
   int i;
 
@@ -1480,7 +1480,7 @@ static int drv_write(struct rfid_reader* reader, int block_start, int number_of_
  */
 int iso15693_inventory_logic(struct rfid_reader* reader, iso15693_inventory_t inventory, rfid_transponders_t* transponders)
 {
-  iso15693_t* iso15693 = (iso15693_t*)reader->private;
+  iso15693_t* iso15693 = (iso15693_t*)reader->opaque;
 
   iso15693_inventory_result_t result;
 
@@ -1567,7 +1567,7 @@ static int drv_inventory(struct rfid_reader* reader, rfid_transponders_t* transp
   memset(&inventory, '\0', sizeof(iso15693_inventory_t));
 
   if((retval = iso15693_inventory_logic(reader, inventory, transponders)) < 0) {
-    iso15693_t* iso15693 = (iso15693_t*)reader->private;
+    iso15693_t* iso15693 = (iso15693_t*)reader->opaque;
     if(iso15693->error == RFID_ERROR_ISO15693_CHECKSUM)
       iso15693->error = RFID_ERROR_TRY_AGAIN;
   }
@@ -1578,7 +1578,7 @@ static int drv_inventory(struct rfid_reader* reader, rfid_transponders_t* transp
 static char* drv_transponder_describe(struct rfid_reader* reader, const rfid_transponder_t* transponder)
 {
   char* str = malloc(512);
-  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->private;
+  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->opaque;
 
   sprintf(str, "uid = 0x%02x%02x%02x%02x%02x%02x%02x%02x\n",
 	  iso15693_transponder->uid[7],
@@ -1611,18 +1611,18 @@ static char* drv_transponder_describe(struct rfid_reader* reader, const rfid_tra
 
 static int drv_transponder_cmp(struct rfid_reader* reader, rfid_transponder_t* transponder_a, rfid_transponder_t* transponder_b)
 {
-  return iso15693_transponder_cmp((iso15693_transponder_t*)transponder_a->private,
-			       (iso15693_transponder_t*)transponder_b->private);
+  return iso15693_transponder_cmp((iso15693_transponder_t*)transponder_a->opaque,
+			       (iso15693_transponder_t*)transponder_b->opaque);
 }
 
 static int drv_transponder_null(struct rfid_reader* reader, rfid_transponder_t* transponder)
 {
-  return iso15693_transponder_null((iso15693_transponder_t*)transponder->private);
+  return iso15693_transponder_null((iso15693_transponder_t*)transponder->opaque);
 }
 
 static int drv_transponder_present(struct rfid_reader* reader, rfid_transponder_t* transponder)
 {
-  iso15693_t* iso15693 = (iso15693_t*)reader->private;
+  iso15693_t* iso15693 = (iso15693_t*)reader->opaque;
   int retval;
 
   if((retval = iso15693_get_system_information(iso15693, transponder)) < 0) {
@@ -1637,8 +1637,8 @@ static int drv_transponder_alloc(struct rfid_reader* reader, rfid_transponder_t*
 {
   rfid_transponder_t* transponder = (rfid_transponder_t*)malloc(sizeof(rfid_transponder_t));
   memset(transponder, '\0', sizeof(rfid_transponder_t));
-  transponder->private = (iso15693_transponder_t*)malloc(sizeof(iso15693_transponder_t));
-  memset(transponder->private, '\0', sizeof(iso15693_transponder_t));
+  transponder->opaque = (iso15693_transponder_t*)malloc(sizeof(iso15693_transponder_t));
+  memset(transponder->opaque, '\0', sizeof(iso15693_transponder_t));
 
   *transponderp = transponder;
 
@@ -1647,7 +1647,7 @@ static int drv_transponder_alloc(struct rfid_reader* reader, rfid_transponder_t*
 
 static int drv_transponder_free(struct rfid_reader* reader, rfid_transponder_t* transponder)
 {
-  free(transponder->private);
+  free(transponder->opaque);
   free(transponder);
 
   return 0;
@@ -1655,29 +1655,29 @@ static int drv_transponder_free(struct rfid_reader* reader, rfid_transponder_t*
 
 static int drv_transponder_clear(struct rfid_reader* reader, rfid_transponder_t* transponder)
 {
-  iso15693_transponder_t* iso15693 = (iso15693_transponder_t*)transponder->private;
+  iso15693_transponder_t* iso15693 = (iso15693_transponder_t*)transponder->opaque;
   memset(iso15693, '\0', sizeof(iso15693_transponder_t));
   memset(transponder, '\0', sizeof(rfid_transponder_t));
-  transponder->private = iso15693;
+  transponder->opaque = iso15693;
 
   return 0;
 }
 
 static int drv_transponder_copy(struct rfid_reader* reader, rfid_transponder_t* to, rfid_transponder_t* from)
 {
-  iso15693_transponder_t* iso15693_to = (iso15693_transponder_t*)to->private;
-  iso15693_transponder_t* iso15693_from = (iso15693_transponder_t*)from->private;
+  iso15693_transponder_t* iso15693_to = (iso15693_transponder_t*)to->opaque;
+  iso15693_transponder_t* iso15693_from = (iso15693_transponder_t*)from->opaque;
 
   memcpy(iso15693_to, iso15693_from, sizeof(iso15693_transponder_t));
   memcpy(to, from, sizeof(rfid_transponder_t));
-  to->private = iso15693_to;
+  to->opaque = iso15693_to;
 
   return 0;
 }
 
 static int drv_transponder_id_get(struct rfid_reader* reader, const rfid_transponder_t* transponder, char** idp)
 {
-  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->private;
+  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->opaque;
 
   char* id = malloc(64);
 
@@ -1698,8 +1698,8 @@ static int drv_transponder_id_get(struct rfid_reader* reader, const rfid_transpo
 
 static int drv_transponder_id_set(struct rfid_reader* reader, rfid_transponder_t* transponder, char* id)
 {
-  iso15693_t* iso15693 = (iso15693_t*)reader->private;
-  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->private;
+  iso15693_t* iso15693 = (iso15693_t*)reader->opaque;
+  iso15693_transponder_t* iso15693_transponder = (iso15693_transponder_t*)transponder->opaque;
   unsigned int id0, id1, id2, id3, id4, id5, id6, id7;
 
   if(sscanf(id, "%x.%x.%x.%x.%x.%x.%x.%x",
@@ -1730,7 +1730,7 @@ static int drv_transponder_id_set(struct rfid_reader* reader, rfid_transponder_t
 
 static int drv_free(rfid_reader_t* reader)
 {
-  free(reader->private);
+  free(reader->opaque);
   free(reader);
   return 0;
 }
@@ -1741,7 +1741,7 @@ static int drv_alloc(rfid_reader_t** readerp)
   iso15693_t* iso15693 = (iso15693_t*)malloc(sizeof(iso15693_t));
   memset(iso15693, '\0', sizeof(iso15693_t));
 
-  reader->private = iso15693;
+  reader->opaque = iso15693;
 
   reader->alloc_f = drv_alloc;
   reader->free_f = drv_free;
