@@ -1506,7 +1506,7 @@ static int drv_iso15693_response(struct rfid_reader* reader, u_int8_t** datap, i
 
 static int drv_free(rfid_reader_t* reader)
 {
-  free(reader->private);
+  free(reader->opaque);
   free(reader);
   return 0;
 }
@@ -1518,7 +1518,7 @@ static int drv_alloc(rfid_reader_t** readerp)
   memset(m2xxh, '\0', sizeof(m2xxh_t));
 
   /* Opaque reader information. */
-  reader->private = m2xxh;
+  reader->opaque = m2xxh;
 
   reader->alloc_f = drv_alloc;
   reader->free_f = drv_free;
