@@ -146,15 +146,21 @@ static int rfid_probe(rfid_t* rfid, rfid_probe_t* probe)
 	rfid_io_init(prober->io, probe->devices[device_index]);
 
 	if(prober->probe_f(prober, probe->drivers[driver_index]) < 0) {
-	  if(prober->error_f(prober) != RFID_ERROR_READER_NOT_FOUND) {
-	    rfid->error = prober->error_f(prober);
-	    if(rfid->verbose) fprintf(stderr, "encountered and error while attempting to probe device %s with driver %s\n", probe->devices[device_index], probe->drivers[driver_index]);
-	    RFID_ERROR_STACK(rfid->verbose);
-	    goto err;
-	  }
-	  if(rfid->verbose) {
-	    fprintf(stderr, "%s with %s: ", prober->io->device, prober->version_f(prober));
-	    fprintf(stderr, "nothing\n");
+	  if(prober->error_f(prober) == ENOENT) {
+	    if(rfid->verbose) {
+	      fprintf(stderr, "%s file not found (ignored)\n", probe->devices[device_index]);
+	    }
+	  } else {
+	    if(prober->error_f(prober) != RFID_ERROR_READER_NOT_FOUND) {
+	      rfid->error = prober->error_f(prober);
+	      if(rfid->verbose) fprintf(stderr, "encountered and error while attempting to probe device %s with driver %s\n", probe->devices[device_index], probe->drivers[driver_index]);
+	      RFID_ERROR_STACK(rfid->verbose);
+	      goto err;
+	    }
+	    if(rfid->verbose) {
+	      fprintf(stderr, "%s with %s: ", prober->io->device, prober->version_f(prober));
+	      fprintf(stderr, "nothing\n");
+	    }
 	  }
 	} else {
 	  if(rfid->verbose) {
