@@ -967,7 +967,7 @@ static int drv_read(struct rfid_reader* reader, int block_start, int number_of_b
     pointer += transponder->bytes_per_block;
   }
   
-  retval = s6350_special_read_block(s6350, (s6350_transponder_t*)transponder->private, block_map, blocks);
+  retval = s6350_special_read_block(s6350, (s6350_transponder_t*)transponder->opaque, block_map, blocks);
 
   free(blocks);
 
@@ -997,7 +997,7 @@ static int drv_write(struct rfid_reader* reader, int block_start, int number_of_
     
     pointer += transponder->bytes_per_block;
 
-    while((retval = s6350_write_block(s6350, (s6350_transponder_t*)transponder->private, &block)) < 0 &&
+    while((retval = s6350_write_block(s6350, (s6350_transponder_t*)transponder->opaque, &block)) < 0 &&
 	    reader->error_f(reader) == RFID_ERROR_TRY_AGAIN) {
       if(s6350->verbose == 1) fprintf(stderr, "!");
     }
@@ -1192,7 +1192,7 @@ static int emulate_iso15693_get_system_information(struct rfid_reader* reader, u
 
   rfid_transponder_t* transponder = 0;
   rfid_reader_t* iso15693_reader = reader->iso15693_reader;
-  iso15693_t* iso15693 = (iso15693_t*)iso15693_reader->private;
+  iso15693_t* iso15693 = (iso15693_t*)iso15693_reader->opaque;
   iso15693_inventory_result_t inventory_result;
 
   if(iso15693_reader->transponder_alloc_f(reader, &transponder)) {
@@ -1452,7 +1452,7 @@ static int drv_iso15693_response(struct rfid_reader* reader, u_int8_t** datap, i
 static char* drv_transponder_describe(struct rfid_reader* reader, const rfid_transponder_t* transponder)
 {
   char* str = malloc(512);
-  s6350_transponder_t* s6350_transponder = (s6350_transponder_t*)transponder->private;
+  s6350_transponder_t* s6350_transponder = (s6350_transponder_t*)transponder->opaque;
 
   sprintf(str, "\
 transponder_id = 0x%02x%02x%02x%02x\n\
@@ -1476,19 +1476,19 @@ bytes_per_block = %d\n\
 
 static int drv_transponder_cmp(struct rfid_reader* reader, rfid_transponder_t* transponder_a, rfid_transponder_t* transponder_b)
 {
-  return s6350_transponder_cmp((s6350_transponder_t*)transponder_a->private,
-			       (s6350_transponder_t*)transponder_b->private);
+  return s6350_transponder_cmp((s6350_transponder_t*)transponder_a->opaque,
+			       (s6350_transponder_t*)transponder_b->opaque);
 }
 
 static int drv_transponder_null(struct rfid_reader* reader, rfid_transponder_t* transponder)
 {
-  return s6350_transponder_null((s6350_transponder_t*)transponder->private);
+  return s6350_transponder_null((s6350_transponder_t*)transponder->opaque);
 }
 
 static int drv_transponder_present(struct rfid_reader* reader, rfid_transponder_t* transponder)
 {
   s6350_t* s6350 = s6350_from_reader(reader);
-  s6350_transponder_t* s6350_transponder = (s6350_transponder_t*)transponder->private;
+  s6350_transponder_t* s6350_transponder = (s6350_transponder_t*)transponder->opaque;
   if(s6350_transponder_details(s6350, s6350_transponder) < 0) {
     RFID_ERROR_STACK(s6350->verbose);
     return -1;
@@ -1505,8 +1505,8 @@ static int drv_transponder_alloc(struct rfid_reader* reader, rfid_transponder_t*
   rfid_transponder_t* transponder = (rfid_transponder_t*)malloc(sizeof(rfid_transponder_t));
 
   memset(transponder, '\0', sizeof(rfid_transponder_t));
-  transponder->private = (s6350_transponder_t*)malloc(sizeof(s6350_transponder_t));
-  memset(transponder->private, '\0', sizeof(s6350_transponder_t));
+  transponder->opaque = (s6350_transponder_t*)malloc(sizeof(s6350_transponder_t));
+  memset(transponder->opaque, '\0', sizeof(s6350_transponder_t));
 
   *transponderp = transponder;
 
@@ -1515,7 +1515,7 @@ static int drv_transponder_alloc(struct rfid_reader* reader, rfid_transponder_t*
 
 static int drv_transponder_free(struct rfid_reader* reader, rfid_transponder_t* transponder)
 {
-  free(transponder->private);
+  free(transponder->opaque);
   free(transponder);
 
   return 0;
@@ -1523,29 +1523,29 @@ static int drv_transponder_free(struct rfid_reader* reader, rfid_transponder_t*
 
 static int drv_transponder_clear(struct rfid_reader* reader, rfid_transponder_t* transponder)
 {
-  s6350_transponder_t* s6350 = (s6350_transponder_t*)transponder->private;
+  s6350_transponder_t* s6350 = (s6350_transponder_t*)transponder->opaque;
   memset(s6350, '\0', sizeof(s6350_transponder_t));
   memset(transponder, '\0', sizeof(rfid_transponder_t));
-  transponder->private = s6350;
+  transponder->opaque = s6350;
 
   return 0;
 }
 
 static int drv_transponder_copy(struct rfid_reader* reader, rfid_transponder_t* to, rfid_transponder_t* from)
 {
-  s6350_transponder_t* s6350_to = (s6350_transponder_t*)to->private;
-  s6350_transponder_t* s6350_from = (s6350_transponder_t*)from->private;
+  s6350_transponder_t* s6350_to = (s6350_transponder_t*)to->opaque;
+  s6350_transponder_t* s6350_from = (s6350_transponder_t*)from->opaque;
 
   memcpy(s6350_to, s6350_from, sizeof(s6350_transponder_t));
   memcpy(to, from, sizeof(rfid_transponder_t));
-  to->private = s6350_to;
+  to->opaque = s6350_to;
 
   return 0;
 }
 
 static int drv_transponder_id_get(struct rfid_reader* reader, const rfid_transponder_t* transponder, char** idp)
 {
-  s6350_transponder_t* s6350_transponder = (s6350_transponder_t*)transponder->private;
+  s6350_transponder_t* s6350_transponder = (s6350_transponder_t*)transponder->opaque;
 
   char* id = malloc(32);
 
@@ -1565,7 +1565,7 @@ static int drv_transponder_id_get(struct rfid_reader* reader, const rfid_transpo
 static int drv_transponder_id_set(struct rfid_reader* reader, rfid_transponder_t* transponder, char* id)
 {
   s6350_t* s6350 = s6350_from_reader(reader);
-  s6350_transponder_t* s6350_transponder = (s6350_transponder_t*)transponder->private;
+  s6350_transponder_t* s6350_transponder = (s6350_transponder_t*)transponder->opaque;
   unsigned int id0, id1, id2, id3, manufacturer, version_number;
 
   if(sscanf(id, "%x.%x.%x.%x.%x.%x",
@@ -1592,7 +1592,7 @@ static int drv_transponder_id_set(struct rfid_reader* reader, rfid_transponder_t
 
 static int drv_free(rfid_reader_t* reader)
 {
-  free(reader->private);
+  free(reader->opaque);
   free(reader);
   return 0;
 }
@@ -1604,7 +1604,7 @@ static int drv_alloc(rfid_reader_t** readerp)
   memset(s6350, '\0', sizeof(s6350_t));
 
   /* Opaque reader information. */
-  reader->private = s6350;
+  reader->opaque = s6350;
 
   reader->alloc_f = drv_alloc;
   reader->free_f = drv_free;
