@@ -37,6 +37,8 @@
 
 #include "rfid.h"
 
+static int verbose = 0;
+
 static void report_error(rfid_t* rfid, const char* message)
 {
   char* str = rfid_strerror(rfid);
@@ -48,12 +50,14 @@ static rfid_t rfid;
 
 static RETSIGTYPE timeout_init(int sig)
 {
-  fprintf(stderr, "\
+  if(verbose) {
+    fprintf(stderr, "\
 \n\
 FAILURE: Timeout attempting to establish communication with RFID reader.\n\
 FAILURE: Make sure a RFID reader is plugged in and turned on.\n\
 \n\
 ");
+  }
   exit(-1);
 }
 
@@ -70,13 +74,17 @@ FAILURE: Make sure a transponder is placed on the RFID reader.\n\
 
 static RETSIGTYPE timeout_write(int sig)
 {
-  fprintf(stderr, "\
+  if(verbose) {
+    fprintf(stderr, "\
 \n\
 FAILURE: Timeout attempting to write information to a transponder.\n\
 FAILURE: Make sure a transponder is placed on the RFID reader.\n\
 \n\
 ");
-  exit(-1);
+  } else {
+    fprintf(stderr, "SKIP\tfunctions tests (no RFID transponder on the RFID reader).\n");
+  }
+  exit(0);
 }
 
 static char* test_string = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
@@ -88,14 +96,16 @@ static int transponder_callback(rfid_t* rfid, int event, const rfid_transponder_
 
   (*count)--;
 
-  fprintf(stderr, "\
+  if(rfid->verbose) {
+    fprintf(stderr, "\
 ========================================\n\
 %s",
-	  transponder_description);
+	    transponder_description);
+  }
 
   free(transponder_description);
   
-  {
+  if(rfid->verbose) {
     int i;
     for(i = 0; i < transponder->data_length; i++)
       fprintf(stderr, "%c(0x%02x)/", transponder->data[i], transponder->data[i]);
@@ -107,8 +117,9 @@ static int transponder_callback(rfid_t* rfid, int event, const rfid_transponder_
     fprintf(stderr, "FAILURE: expected %s\n", test_string);
     return RFID_CALLBACK_ERROR;
   }
-  
-  fprintf(stderr, "=> %d more read attempt to go\n", *count);
+
+  if(rfid->verbose)
+    fprintf(stderr, "=> %d more read attempt to go\n", *count);
 
   return *count > 0 ? RFID_CALLBACK_OK : RFID_CALLBACK_END;
 }
@@ -116,7 +127,6 @@ static int transponder_callback(rfid_t* rfid, int event, const rfid_transponder_
 int main(int argc, char** argv)
 {
   int timeout = 5;
-  int verbose = 0;
   char* driver = RFID_DRIVER_GUESS;
   char* device = RFID_DEVICE_GUESS;
 
@@ -138,6 +148,8 @@ int main(int argc, char** argv)
 
   rfid.reader->verbose_f(rfid.reader, rfid.verbose);
 
+  fprintf(stderr, "Testing rfid(3) with %s using driver %s\n", rfid_version(), rfid.reader->version_f(rfid.reader));
+
   signal(SIGALRM, timeout_write);
 
   alarm(timeout);
@@ -155,12 +167,14 @@ int main(int argc, char** argv)
 
     transponder_description = rfid_transponder_describe(&rfid, transponder);
 
-    fprintf(stderr, "\
+    if(rfid.verbose) {
+      fprintf(stderr, "\
 ========================================\n\
 Wrote string %s to transponder:\n\
 %s",
 	    test_string,
 	    transponder_description);
+    }
     free(transponder_description);
     rfid_transponder_free(&rfid, transponder);
   }
